Enum OutputType
#[non_exhaustive]pub enum OutputType {
Bare,
Wpkh,
Wsh,
ShWpkh,
ShWsh,
Sh,
Tr,
}Expand description
The various output types supported by the Bitcoin network.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bare
An output of type: pay-to-pubkey or pay-to-pubkey-hash.
Wpkh
A pay-to-witness-pubkey-hash output (P2WPKH).
Wsh
A pay-to-witness-script-hash output (P2WSH).
ShWpkh
A nested segwit output, pay-to-witness-pubkey-hash nested in a pay-to-script-hash.
ShWsh
A nested segwit output, pay-to-witness-script-hash nested in a pay-to-script-hash.
Sh
A pay-to-script-hash output excluding wrapped segwit (P2SH).
Tr
A taproot output (P2TR).
Implementations
impl OutputType
impl OutputType
pub fn signing_algorithm(&self) -> SigningAlgorithm
pub fn signing_algorithm(&self) -> SigningAlgorithm
The signing algorithm used to sign this output type.