Struct PsbtSighashType
pub struct PsbtSighashType { /* private fields */ }Expand description
A Signature hash type for the corresponding input.
As of taproot upgrade, the signature hash type can be either EcdsaSighashType or
TapSighashType but it is not possible to know directly which signature hash type the user is
dealing with. Therefore, the user is responsible for converting to/from PsbtSighashType
from/to the desired signature hash type they need.
Implementations
impl PsbtSighashType
impl PsbtSighashType
pub fn ecdsa_hash_ty(
self,
) -> Result<EcdsaSighashType, NonStandardSighashTypeError>
pub fn ecdsa_hash_ty( self, ) -> Result<EcdsaSighashType, NonStandardSighashTypeError>
Returns the EcdsaSighashType if the PsbtSighashType can be
converted to one.
pub fn taproot_hash_ty(self) -> Result<TapSighashType, InvalidSighashTypeError>
pub fn taproot_hash_ty(self) -> Result<TapSighashType, InvalidSighashTypeError>
Returns the TapSighashType if the PsbtSighashType can be
converted to one.
pub fn from_u32(n: u32) -> PsbtSighashType
pub fn from_u32(n: u32) -> PsbtSighashType
Creates a PsbtSighashType from a raw u32.
Allows construction of a non-standard or non-valid sighash flag
(EcdsaSighashType, TapSighashType respectively).
pub fn to_u32(self) -> u32
pub fn to_u32(self) -> u32
Converts PsbtSighashType to a raw u32 sighash flag.
No guarantees are made as to the standardness or validity of the returned value.